@@ -263,7 +263,7 @@ activate_service (GeditDBus *dbus,
 	                                   "org.freedesktop.DBus",
 	                                   "StartServiceByName",
 	                                   g_variant_new ("(su)", "org.gnome.gedit", 0),
-					   G_VARIANT_TYPE ("(su)"),
+	                                   G_VARIANT_TYPE ("(u)"),
 	                                   G_DBUS_CALL_FLAGS_NONE,
 	                                   -1,
 	                                   NULL,
